package de.samdev.colorrunner.game.renderer;

import com.badlogic.gdx.Gdx;
import com.badlogic.gdx.graphics.GL20;
import com.badlogic.gdx.graphics.OrthographicCamera;
import com.badlogic.gdx.graphics.g2d.BitmapFont;
import com.badlogic.gdx.graphics.g2d.SpriteBatch;
import com.badlogic.gdx.graphics.g2d.TextureAtlas;
import com.badlogic.gdx.graphics.glutils.ShapeRenderer;
import com.badlogic.gdx.graphics.glutils.ShapeRenderer.ShapeType;

public abstract class AbstractGameRenderer {
	private final static float GAME_HEIGHT = 512;
	private final static float MIN_GAME_WIDTH = 672; // ~ 512 * (4/3)
	private final static float MAX_GAME_WIDTH = 1024; // ~ 512 * (2/1) // ~~ 16:9

	private OrthographicCamera cam;
	protected ShapeRenderer shapeRenderer;

	protected BitmapFont font = new BitmapFont();
	protected SpriteBatch spriteBatch = new SpriteBatch();

	public AbstractGameRenderer(float width, float height) {
		cam = new OrthographicCamera();

		shapeRenderer = new ShapeRenderer();

		resize(width, height);
	}

	public void render() {
		Gdx.gl.glClearColor(1, 0, 1, 1f);
		Gdx.gl.glClear(GL20.GL_COLOR_BUFFER_BIT);

		// #################

		shapeRenderer.begin(ShapeType.Filled);

		shapeRenderer.setColor(0.22f, 0.22f, 0.22f, 1);
		shapeRenderer.rect(0, 0, MIN_GAME_WIDTH, GAME_HEIGHT);

		shapeRenderer.end();

		doRender();
	}

	public void resize(float width, float height) {
		float cam_width = (width / height) * GAME_HEIGHT;

		if (cam_width < MIN_GAME_WIDTH)
			Gdx.app.error("SIZE", "Minimal aspect ratio is 4:3");

		if (cam_width > MAX_GAME_WIDTH)
			Gdx.app.error("SIZE", "Maximal aspect ratio is 2:1");

		cam.setToOrtho(true, cam_width, GAME_HEIGHT);
		shapeRenderer.setProjectionMatrix(cam.combined);
	}

	protected void renderDebug(String s) {
		spriteBatch.begin();
		font.setColor(0, 1, 0, 1);
		font.draw(spriteBatch, s, 0, Gdx.graphics.getHeight());
		spriteBatch.end();
	}
	
	public abstract void doRender();
}
