package de.samdev.colorrunner.screens.gameScreen;

import com.badlogic.gdx.Gdx;
import com.badlogic.gdx.InputMultiplexer;
import com.badlogic.gdx.Screen;
import com.badlogic.gdx.graphics.GL20;
import com.badlogic.gdx.input.GestureDetector;

import de.samdev.colorrunner.game.renderer.CRGameRenderer;
import de.samdev.colorrunner.game.world.CRGameWorld;
import de.samdev.colorrunner.input.CRGameInputProcessor;
import de.samdev.colorrunner.input.GameInputListener;
import de.samdev.colorrunner.input.SwipeDirection;

public class GameScreen implements Screen, GameInputListener {
	private final static float GAME_WIDTH = 500;
	
	private CRGameWorld world;
	private CRGameRenderer renderer;

	public GameScreen() {
		world = new CRGameWorld(); // initialize world
		renderer = new CRGameRenderer(world, Gdx.graphics.getWidth(), Gdx.graphics.getHeight()); // initialize renderer
	}

	@Override
	public void render(float delta) {

        world.update(delta);
        renderer.render();
	}

	@Override
	public void resize(int width, int height) {
		Gdx.app.log("GameScreen", "resize called");
		
		float gameHeight = height / (width / GAME_WIDTH);
		
		float gameX = 0;
		float gameY = (height - gameHeight) / 2;
		
		renderer.resize(width, height);
	}

	@Override
	public void show() {
		CRGameInputProcessor ip = new CRGameInputProcessor(this);
		Gdx.input.setInputProcessor(new InputMultiplexer(ip, new GestureDetector(ip)));

		Gdx.app.log("GameScreen", "show called");
	}

	@Override
	public void hide() {
		Gdx.input.setInputProcessor(null);

		Gdx.app.log("GameScreen", "hide called");
	}

	@Override
	public void pause() {
		Gdx.app.log("GameScreen", "pause called");
	}

	@Override
	public void resume() {
		Gdx.app.log("GameScreen", "resume called");
	}

	@Override
	public void dispose() {
		Gdx.app.log("GameScreen", "dispose called");
	}

	@Override
	public void doJump() {

		Gdx.app.log("GameScreen", "[DO] Jump");
	}

	@Override
	public void switchColor(SwipeDirection sd) {

		Gdx.app.log("GameScreen", "[DO] Switch + " + sd.toString());
	}

}
